@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuToPS.cpp,v 1.24 2007/03/25 20:48:31 leonb Exp $
-// $Name: release_3_5_20 $
+// $Id: DjVuToPS.cpp,v 1.25 2007/12/02 03:58:29 leonb Exp $
+// $Name: release_3_5_20_2 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -269,7 +269,7 @@ DjVuToPS::DjVuToPS(void)
   DEBUG_MAKE_INDENT(3);
   DEBUG_MSG("Initializing dig2hex[]\n");
   // Creating tables for bin=>text translation
-  static char * dig2hex="0123456789ABCDEF";
+  static const char * dig2hex="0123456789ABCDEF";
   int i;
   for(i=0;i<256;i++)
     {
