@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GSmartPointer.cpp,v 1.12 2007/03/25 20:48:32 leonb Exp $
-// $Name: release_3_5_20 $
+// $Id: GSmartPointer.cpp,v 1.15 2007/12/05 18:58:06 leonb Exp $
+// $Name: release_3_5_20_2 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -110,6 +110,10 @@ void
 GPEnabled::ref()
 {
   gcsCounter.lock();
+#if PARANOID_DEBUG
+  if (count <= 0)
+    G_THROW( ERR_MSG("GSmartPointer.suspicious") );
+#endif
   count++;
   gcsCounter.unlock();
 }
@@ -118,10 +122,16 @@ void
 GPEnabled::unref()
 {
   gcsCounter.lock();
-  if (! --count) 
-    count = -1;
+#if PARANOID_DEBUG
+  if (count <= 0)
+    G_THROW( ERR_MSG("GSmartPointer.suspicious") );
+#endif
+  int cnt = count;
+  if (! --cnt) 
+    cnt = -1;
+  count = cnt;
   gcsCounter.unlock();
-  if (count < 0)
+  if (cnt < 0)
     destroy();
 }
 
@@ -144,10 +154,12 @@ GPBase::assign (GPEnabled *nptr)
     {
       GPEnabled *old = ptr;
       ptr = nptr;
-      if (! --old->count) 
-        old->count = -1;
+      int cnt = old->count;
+      if (! --cnt) 
+        cnt = -1;
+      old->count = cnt;
       gcsCounter.unlock();      
-      if (old->count < 0)
+      if (cnt < 0)
         old->destroy();
     }
   else
@@ -170,10 +182,12 @@ GPBase::assign (const GPBase &sptr)
     {
       GPEnabled *old = ptr;
       ptr = sptr.ptr;
-      if (! --old->count) 
-        old->count = -1;
+      int cnt = old->count;
+      if (! --cnt) 
+        cnt = -1;
+      old->count = cnt;
       gcsCounter.unlock();      
-      if (old->count < 0)
+      if (cnt < 0)
         old->destroy();
     }
   else
