@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GSmartPointer.h,v 1.14 2007/05/19 03:07:33 leonb Exp $
-// $Name: release_3_5_20 $
+// $Id: GSmartPointer.h,v 1.15 2007/12/02 15:13:17 leonb Exp $
+// $Name: release_3_5_20_2 $
 
 #ifndef _GSMARTPOINTER_H_
 #define _GSMARTPOINTER_H_
@@ -88,7 +88,7 @@
 // <http://prdownloads.sourceforge.net/djvu/DjVu2_2b-src.tgz>.
 
     @version 
-    #$Id: GSmartPointer.h,v 1.14 2007/05/19 03:07:33 leonb Exp $# 
+    #$Id: GSmartPointer.h,v 1.15 2007/12/02 15:13:17 leonb Exp $# 
     @args
 */
 //@{
@@ -367,6 +367,10 @@ GPBase::~GPBase()
 inline GPEnabled* 
 GPBase::get() const
 {
+#if PARANOID_DEBUG
+  if (ptr && ptr->get_count() <= 0)
+    *(int*)0=0;
+#endif
   return ptr;
 }
 
@@ -413,12 +417,20 @@ GP<TYPE>::operator TYPE* () const
 template <class TYPE> inline TYPE*
 GP<TYPE>::operator->() const
 {
+#if PARANOID_DEBUG
+  if (ptr && ptr->get_count() <= 0)
+    *(int*)0=0;
+#endif
   return (TYPE*) ptr;
 }
 
 template <class TYPE> inline TYPE&
 GP<TYPE>::operator*() const
 {
+#if PARANOID_DEBUG
+  if (ptr && ptr->get_count() <= 0)
+    *(int*)0=0;
+#endif
   return *(TYPE*) ptr;
 }
 
