@@ -53,7 +53,7 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 
-/* $Id: ddjvuapi.cpp,v 1.85 2007/03/25 20:48:35 leonb Exp $ */
+/* $Id: ddjvuapi.cpp,v 1.86 2007/12/02 03:58:29 leonb Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -3458,7 +3458,7 @@ ddjvu_document_get_outline(ddjvu_document_t *document)
 // S-Expressions (text)
 
 static struct zone_names_s {
-  char *name;
+  const char *name;
   DjVuTXT::ZoneType ztype;
   char separator;
 } zone_names[] = {
