@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 // -------------------------------------------------------------------
 */
-/* $Id: miniexp.h,v 1.16 2007/11/09 19:04:22 leonb Exp $ */
+/* $Id: miniexp.h,v 1.18 2007/12/02 03:58:29 leonb Exp $ */
 
 #ifndef MINIEXP_H
 #define MINIEXP_H
@@ -323,7 +323,7 @@ MINILISPAPI miniexp_t miniexp_concat(miniexp_t l);
      garbage collection: miniexp_cons(), miniexp_object(),
      miniexp_string(), miniexp_substring(),
      miniexp_concat(), miniexp_pprin(), miniexp_pprint(),
-     miniexp_gc(), and miniexp_release_gc_lock().  A
+     miniexp_gc(), and minilisp_release_gc_lock().  A
      function that does not cause calls to these functions
      does not need to bother about minivars.
 
@@ -345,8 +345,8 @@ MINILISPAPI miniexp_t miniexp_concat(miniexp_t l);
    Wrappers are provided to allocate minivars and to access
    their value. This is somehow inconvenient.  It might be
    more practical to control the garbage collector
-   invocations with <miniexp_acquire_gc_lock()> and
-   <miniexp_release_gc_lock()>...  */
+   invocations with <minilisp_acquire_gc_lock()> and
+   <minilisp_release_gc_lock()>...  */
    
 
 /* minilisp_gc --
@@ -550,8 +550,8 @@ typedef void minilisp_mark_t(miniexp_t *pp);
 /* minivar_t --
    A class for protected garbage collector variables. */
 
-MINILISPAPI 
-class minivar_t 
+class MINILISPAPI 
+minivar_t 
 {
   miniexp_t data;
   minivar_t *next;
@@ -579,8 +579,8 @@ public:
    The base class for c++ objects 
    represented by object expressions. */
 
-MINILISPAPI 
-class miniobj_t {
+class MINILISPAPI 
+miniobj_t {
  public:
   virtual ~miniobj_t();
 
