@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: csepdjvu.cpp,v 1.26 2007/09/29 17:51:43 leonb Exp $
-// $Name: release_3_5_20 $
+// $Id: csepdjvu.cpp,v 1.27 2007/11/30 14:39:26 leonb Exp $
+// $Name: release_3_5_20_2 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -136,7 +136,7 @@
     @author
     L\'eon Bottou <leonb@research.att.com>
     @version
-    #$Id: csepdjvu.cpp,v 1.26 2007/09/29 17:51:43 leonb Exp $# */
+    #$Id: csepdjvu.cpp,v 1.27 2007/11/30 14:39:26 leonb Exp $# */
 //@{
 //@}
 
@@ -1427,6 +1427,7 @@ Comments::make_chunks(IFFByteStream &iff)
         minilisp_outbs = bsb;
         minilisp_puts = minilisp_outfunc;
         minivar_t exor = miniexp_cons(miniexp_symbol("xor"),miniexp_nil);
+        minivar_t zstr = miniexp_string("");
         for (GPosition p = links; p; ++p)
           {
             GP<LnkMark> mark = links[p];
@@ -1439,7 +1440,7 @@ Comments::make_chunks(IFFByteStream &iff)
             area = miniexp_cons(miniexp_number(mark->r.xmin), area);
             area = miniexp_cons(miniexp_symbol("rect"),area);
             expr = miniexp_cons(area, expr);
-            expr = miniexp_cons(miniexp_nil, expr);
+            expr = miniexp_cons(zstr, expr);
             expr = miniexp_cons(url, expr);
             expr = miniexp_cons(miniexp_symbol("maparea"), expr);
             miniexp_pprint(expr, 72);
