@@ -53,7 +53,7 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: djvups.cpp,v 1.19 2007/03/25 20:48:36 leonb Exp $
+// $Id: djvups.cpp,v 1.20 2007/12/02 04:14:45 leonb Exp $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -220,8 +220,8 @@ main(int argc, char **argv)
   int i;
   int optc = 0;
   char **optv;
-  char *infile = 0;
-  char *outfile = 0;
+  const char *infile = 0;
+  const char *outfile = 0;
   FILE *fout;
 
   /* Sort options */
